summaryrefslogtreecommitdiff
path: root/src/lib/film.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/film.h')
-rw-r--r--src/lib/film.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/film.h b/src/lib/film.h
index c6c8403cb..649768c7a 100644
--- a/src/lib/film.h
+++ b/src/lib/film.h
@@ -323,8 +323,8 @@ public:
void set_reel_length (int64_t);
void set_upload_after_make_dcp (bool);
- /** Emitted when some property has of the Film has changed */
- mutable boost::signals2::signal<void (Property)> Changed;
+ /** Emitted when some property has of the Film is about to change or has changed */
+ mutable boost::signals2::signal<void (ChangeType, Property)> Change;
/** Emitted when some property of our content has changed */
mutable boost::signals2::signal<void (ChangeType, boost::weak_ptr<Content>, int, bool)> ContentChange;